@@ -519,7 +519,7 @@ def FieldDetermination(Fields,plot=False,**kwargs):
             fields = fields.append(df2, ignore_index=True)
     else:
         for v in posit:
-            df2 = pd.DataFrame([[v, posit[v][1], posit[v][2],posit[v][3],posit[v][4],posit[v][5],posit[v][6],posit[v][7]]], 
+            df2 = pd.DataFrame([[posit[v][0], posit[v][1], posit[v][2],posit[v][3],posit[v][4],posit[v][5],posit[v][6],posit[v][7]]], 
                                  columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y','height', 'width'])
             rect.append(patches.Rectangle((float(posit[v][4]),float(posit[v][5])), float(posit[v][6]), float(posit[v][7]), linewidth=1, edgecolor=obj_color, facecolor='none'))
             circle.append(plt.Circle((float(posit[v][1]),float(posit[v][2])), float(posit[v][3]), color=obj_color,fill = False))
